define(
        [
            'jquery',
            'ko',
            'uiComponent',
            'Magento_Customer/js/customer-data',
            'underscore',
            'Magento_Ui/js/modal/modal',
            'mage/cookies'
        ],
        function ($, ko, Component, customerData, _, modal) {
            "use strict";
            return Component.extend({

                geoipData: {},
                initialize: function () {

                    window.filoblu_geoip_misfits.geoipmisfitsclass = this;

                    var me = this;
                    // Cookie Var

                    this.geoipData["misfits_cookie"] = ko.observable();
                    this.geoipData["misfits_cookie"]($.mage.cookies.get(window.filoblu_geoip_misfits.misfits_cookie_name));

                    var geoipData = customerData.get('geoip-data-misfits');
                    this.update(geoipData());
                    geoipData.subscribe(function (updatedGeoIpData) {

                        this.update(updatedGeoIpData);

                        if (!this.getGeoipParam("misfits_cookie") && this.getGeoipParam("must_show")) {

                            var optionsPopup = {
                                type: 'popup',
                                responsive: true,
                                modalClass: 'geoipMisfitsModal',
                                innerScroll: true,
                                autoOpen: true,
                                buttons: [],
                                closed: function () {
                                    me._setCookieMisfits();
                                },
                                opened: function ($Event) {

                                }
                            };

                            var popup = modal(optionsPopup, $(window.filoblu_geoip_misfits.popup_id));

                            $("body").addClass("geoip-misfits-popup-showing");

                            $("body").on('click', window.filoblu_geoip_misfits.btn_back, function (e) {
                                e.preventDefault();
                                $(window.filoblu_geoip_misfits.popup_id).removeClass("selected-step-second").addClass("selected-step-first");
                            });

                            $("body").on('click', window.filoblu_geoip_misfits.btn_close_advice, function (e) {
                                e.preventDefault();
                                $(window.filoblu_geoip_misfits.popup_id).modal("closeModal");
                            });

                            $("body").on('click', window.filoblu_geoip_misfits.btn_continue_geoloc, function (e) {
                                e.preventDefault();
                                me._countryAjax($(this).attr("data-store-url"), $(this).attr("data-store-id"), $(this).attr("data-country-id"), $(this).attr("data-country-name"));
                            });

                            $("body").on('click', window.filoblu_geoip_misfits.language_link, function (e) {

                                e.preventDefault();
                                me._languageAjax($(this).attr("href"), $(this).attr("data-store-id"), $(this).attr("data-country-id"));
                            });

                            $("body").on("click", window.filoblu_geoip.shipping_to_link, function (e) {
                                e.preventDefault();
                                $(window.filoblu_geoip_misfits.popup_id).modal("closeModal");
                            });
                        }
                    }, this);

                    customerData.reload(['geoip-data-misfits'], false);

                    return this._super();
                },
                _setCookieMisfits: function () {
                    if (!$.mage.cookies.get(window.filoblu_geoip_misfits.misfits_cookie_name)) {
                        var toDay = new Date();//for getting todays date.
                        toDay.setTime(toDay.getTime());
                        var expaireTime = window.filoblu_geoip_misfits.cookie_duration * 1000;
                        var expaireDate = new Date(toDay.getTime() + (expaireTime));

                        $.mage.cookies.set(window.filoblu_geoip_misfits.misfits_cookie_name, '1', {"expires": expaireDate});
                    }
                },
                _countryAjax: function (url, store_id, country_id, country_name) {

                    var me = this;

                    $.ajax({
                        showLoader: true,
                        url: url + "geoip/change/country",
                        data: "store_id=" + store_id + "&country_id=" + country_id,
                        type: "POST",
                        dataType: 'json'
                    }).done(function (languages) {

                        if (languages.length == 1) {
                            me._setCookieMisfits();
                            window.location.href = languages[0].url;
                        } else {
                            var languageList = "";
                            languages.forEach(function (entry) {
                                var languageName = "";

                                languageName = entry.name;
                                languageList += "<a class='language-link-misfits' href='" + entry.url + "' data-store-id='" + entry.store_id + "' data-country-id='" + entry.country_id + "' >" + languageName + "</a>";
                            });
                            $(window.filoblu_geoip_misfits.language_list_container).html(languageList);
                            $(window.filoblu_geoip_misfits.popup_id).removeClass("selected-step-first").addClass("selected-step-second");
                        }
                    });
                },
                _languageAjax: function (url, store_id, country_id) {

                    var me = this;

                    $.ajax({
                        showLoader: true,
                        url: url + "geoip/change/language",
                        data: "store_id=" + store_id + "&country_id=" + country_id,
                        type: "POST",
                        dataType: 'json'
                    }).done(function (result) {

                        if (result) {
                            me._setCookieMisfits();
                            window.location.href = result.url;
                        }
                    });
                },

                update: function (updatedGeoipData) {
                    _.each(updatedGeoipData, function (value, key) {

                        if (!this.geoipData.hasOwnProperty(key)) {
                            this.geoipData[key] = ko.observable();
                        }
                        this.geoipData[key](value);
                    }, this);
                },
                /**
                 * Get geoip data param by name.
                 * @param {String} name
                 * @returns {*}
                 */
                getGeoipParam: function (name) {
                    if (!_.isUndefined(name)) {
                        if (!this.geoipData.hasOwnProperty(name)) {
                            this.geoipData[name] = ko.observable();
                        }
                    }

                    return this.geoipData[name]();
                }

            });
        }
);